# prom433

![Docker Image Version (latest semver)](https://img.shields.io/docker/v/andrewjw/prom433)
[![Coverage Status](https://coveralls.io/repos/github/andrewjw/prom433/badge.svg?branch=master)](https://coveralls.io/github/andrewjw/prom433?branch=master)

Exposes Prometheus metrics based on data received by rtl_433

